#!/usr/bin/python

###################################
# Data Validator By R&D ICWR      #
# Copyright (c)2020 - Afrizal F.A #
###################################

import re

class validator():
    def __init__(self,key,data):
        self.key=key
        self.data=data

    def proc(self,key,data):
        valid_data=[]
        for x in key:
            array_data=re.findall(x.lower(),data.lower())
            if array_data:
                valid_data.append(array_data)
        return valid_data

    def matching(self):
        if type(self.data) == list:
            valid_data=[]
            i=0
            for x in self.data:
                i=i+1
                valid_data.append({i:self.proc(self.key,x)})
            return valid_data
        else:
            return self.proc(self.key,self.data)



from distutils.core import setup

setup(
  name = 'pydval',
  packages = ['pydval'],
  version = '0.0.2',
  license='MIT',
  description = 'Python Data Validator',
  author = 'Afrizal F.A',
  author_email = 'afrizal.fadillah46@gmail.com',
  url = 'https://github.com/ICWR-TECH/Pydval',
  download_url = 'https://github.com/ICWR-TECH/Pydval/raw/master/pydval-0.0.2.tar.gz',
  keywords = ['pydval'],
  classifiers=[
    'Development Status :: 3 - Alpha',
    'Intended Audience :: Developers',
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python :: 3.8',
  ],
)
